==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ConsoleAuthenticationFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleAuthenticationFluentImpl<A extends ConsoleAuthenticationFluent<A>> extends BaseFluent<A> implements ConsoleAuthenticationFluent<A>{
  public ConsoleAuthenticationFluentImpl() {
  }
  public ConsoleAuthenticationFluentImpl(ConsoleAuthentication instance) {
    this.withLogoutRedirect(instance.getLogoutRedirect()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String logoutRedirect;
  private Map<String,Object> additionalProperties;
  public String getLogoutRedirect() {
    return this.logoutRedirect;
  }
  public A withLogoutRedirect(String logoutRedirect) {
    this.logoutRedirect=logoutRedirect; return (A) this;
  }
  public Boolean hasLogoutRedirect() {
    return this.logoutRedirect != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleAuthenticationFluentImpl that = (ConsoleAuthenticationFluentImpl) o;
    if (logoutRedirect != null ? !logoutRedirect.equals(that.logoutRedirect) :that.logoutRedirect != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(logoutRedirect,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (logoutRedirect != null) { sb.append("logoutRedirect:"); sb.append(logoutRedirect + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ConsoleAuthenticationFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleAuthenticationFluentImpl<A extends ConsoleAuthenticationFluent<A>> extends BaseFluent<A> implements ConsoleAuthenticationFluent<A>{
  public ConsoleAuthenticationFluentImpl() {
  }
  public ConsoleAuthenticationFluentImpl(ConsoleAuthentication instance) {
    if (instance != null) {
      this.withLogoutRedirect(instance.getLogoutRedirect());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String logoutRedirect;
  private Map<String,Object> additionalProperties;
  public String getLogoutRedirect() {
    return this.logoutRedirect;
  }
  public A withLogoutRedirect(String logoutRedirect) {
    this.logoutRedirect=logoutRedirect; return (A) this;
  }
  public Boolean hasLogoutRedirect() {
    return this.logoutRedirect != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleAuthenticationFluentImpl that = (ConsoleAuthenticationFluentImpl) o;
    if (!java.util.Objects.equals(logoutRedirect, that.logoutRedirect)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(logoutRedirect,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (logoutRedirect != null) { sb.append("logoutRedirect:"); sb.append(logoutRedirect + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
